@@ -84,10 +84,6 @@ sub run {
 
         _check_dep5_copyright($info, $contents);
         _check_apache_notice_files($info, $group, $contents);
-
-        tag 'incomplete-creative-commons-license'
-          if $contents =~ m/\nLicense: CC-/m
-          and $contents !~ m/not a law firm/i;
     }
     return;
 }
@@ -290,7 +286,8 @@ sub _parse_dep5 {
       and none { defined $first_para->{$_} } qw(comment disclaimer);
     tag 'missing-explanation-for-repacked-upstream-tarball'
       if $info->repacked
-      and none { defined $first_para->{$_} } qw(comment files-excluded);
+      and none { defined $first_para->{$_} } qw(comment files-excluded)
+      and ($first_para->{'source'} // '') =~ m{^https?://};
 
     my (undef, $full_license_field, undef,@short_licenses_field)
       =parse_license($first_para->{'license'}, 1);
@@ -333,7 +330,8 @@ sub _parse_dep5 {
         if (defined $license and not defined $files) {
             my (undef, $full_license, $short_license,@short_licenses)
               = parse_license($license, $current_line);
-
+            check_incomplete_creative_commons_license($short_license,
+                $license, $current_line);
             # Standalone license paragraph
             if (defined($short_license) and $short_license =~ /\s++\|\s++/) {
                 tag 'pipe-symbol-used-as-license-disjunction', $short_license,
@@ -430,6 +428,8 @@ sub _parse_dep5 {
 
             my ($found_license, $full_license, $short_license, @short_licenses)
               = parse_license($license, $current_line);
+            check_incomplete_creative_commons_license($short_license,
+                $license, $current_line);
             if (defined($short_license) and $short_license =~ /\s++\|\s++/) {
                 tag 'pipe-symbol-used-as-license-disjunction', $short_license,
                   "(paragraph at line $current_line)";
@@ -690,6 +690,20 @@ sub check_files_excluded {
     return;
 }
 
+sub check_incomplete_creative_commons_license {
+    my ($short_license, $license, $current_line) = @_;
+    return unless $short_license and $license;
+
+    my $num_lines = $license =~ tr/\n//;
+    tag 'incomplete-creative-commons-license', $short_license,
+      "(paragraph at line $current_line)"
+      if $short_license =~ m,^cc-,
+      and $num_lines > 0
+      and $num_lines < 20;
+
+    return;
+}
+
 1;
 
 # Local Variables:
